package com.crm.manager.service;

import com.crm.rely.backend.core.dto.control.panel.statistics.*;
import com.crm.rely.backend.core.entity.control.panel.statistics.ControlPanelStatisticsEntity;
import com.crm.rely.backend.exception.ServiceException;

import java.util.List;

/**
 * @Author: houn
 * @Date: 2020/8/13 13:55
 * @Description:
 */
public interface ControlPanelService {


    List<FinanceStatisticsDto> financeStatistics() throws ServiceException;

    FinanceStatisticsDto financeStatistics(ControlPanelStatisticsEntity entity) throws ServiceException;

    FinanceBalancePendingStatisticsDto financeBalancePendingStatistics() throws ServiceException;

    ManagerStatisticsDto managerStatistics() throws ServiceException;

    LegalAffairsStatisticsDto legalAffairsStatistics() throws ServiceException;

    MarketStatisticsDto marketStatistics() throws ServiceException;

    SaleStatisticsDto saleStatistics() throws ServiceException;
}
